"""This module holds every constant for the library."""


# Port configurations
BAUD_RATE = 115200
PARITY = "N"
BYTE_SIZE = 8
STOP_BITS = 2
XON_XOFF = 0
RTS_CTS = 0


# Write constants
BOTTOM_ADDRESS = 0
TOP_ADDRESS = 2 ** 12
WORD_LENGTH = 5
